==> apache-pulsar-2.10.0-src.tar.gz: apache-pulsar-2.10.0-src/site2/website/blog/2020-09-01-pulsar-summit-asia-2020-cfp.md <==
---
author: Jennifer Huang  
authorURL: https://twitter.com/Jennife06125739  
title: Pulsar Summit Asia 2020 CFP is now open

---

The Pulsar Summit is an annual conference dedicated to the Apache Pulsar community. The summit brings together an international audience of CTOs/CIOs, developers, data architects, data scientists, Apache Pulsar committers/contributors, and the messaging and streaming community. Together, they share experiences, ideas, and insights on Pulsar and its growing community, and receive hands-on training sessions led by Pulsar experts.

After a very successful Pulsar Summit Virtual Conference in June, we have decided to present our Pulsar Summit Asia 2020 in the same way on November 28-29, 2020. The two-day conference will be free to attend! Are you interested in presenting? Suggested topics include Pulsar use cases, operations, technology deep dive, and ecosystem. CFP and registration are now open!

![](../img/pulsar-summit-asia-2020.png)

## Speak at Pulsar Summit
The opportunity to speak at the second global Pulsar Summit is a great chance to participate in the rapidly growing Apache Pulsar community. Join us for the opportunity to be on stage with top Pulsar thought-leaders, including Apache Pulsar PMC members Sijie Guo and Jia Zhai from [StreamNative](https://streamnative.io/), Penghui Li from Zhaopin.com, Nozomi Kurihara from [Yahoo Japan Corporation](https://about.yahoo.co.jp/), and other community leaders such as Dezhi Liu from [Tencent](https://www.tencent.com/en-us), Vincent Xie from [Orange Finance](https://www.bestpay.com.cn/). Proposals for speaker presentations are currently being accepted. Suggested topics include Pulsar use cases, operations, technology deep dive, and ecosystem. Submissions are open until **October 14, 2020**.

If you have questions about submitting a proposal, or want some feedback or advice in general, please do not hesitate to reach out to [organizers@pulsar-summit.org](mailto:organizers@pulsar-summit.org). We are happy to help out! Details are available on the [CFP website](https://pulsar-summit.org/en/event/asia-2020/cfp).

## Dates to remember
- CFP opens: September 1, 2020
- CFP closes: October 21, 2020 - 23:59 (CST: China Standard Time/UTC+8 time zone)
- CFP notification: October 28, 2020
- Schedule announcement: November 4, 2020

## Speaker benefits
When your speaking proposal is approved, you will enjoy the following benefits:

- The opportunity to expand your network and raise your profile in the Apache Pulsar community.
- The chance to demonstrate your experience and deep knowledge in the rapidly growing event streaming space.
- Your name, title, company, and bio will be featured on the Pulsar Summit Asia 2020 website.
- Your session will be added to the Pulsar Summit YouTube Channel and promoted on Twitter and LinkedIn.
- A professionally produced video of your presentation.

## Speaker requirements
In addition to your talk, we ask that you actively participate in promoting the event via your personal and company channels. These include posting on your Twitter, LinkedIn, WeChat, Weibo, blog and other channels. We would also like to work directly with your marketing team on co-marketing opportunities. These include, but are not limited to, posting to your company’s Twitter, LinkedIn, WeChat and other developer communities and sending a dedicated Pulsar Summit email to your company’s email list. Contact us at [organizers@pulsar-summit.org](mailto:organizers@pulsar-summit.org) with any questions. 

## Registration
If you are interested in attending Pulsar Summit Asia 2020, please sign in Hopin and [checkout our event](https://hopin.to/events/pulsar-summit-asia-2020). Your ideas are very important to us, and we will prepare the content accordingly. 

After you checkout the event in Hopin, you will be notified with the event update at the first time when announcing.

## Sponsor Pulsar Summit
Pulsar Summit is a community run conference and your support is needed. Sponsoring this event will provide a great opportunity for your organization to further engage with the Apache Pulsar community. [Contact us](mailto:partners@pulsar-summit.org) to learn more.

Help us make #PulsarSummit 2020 a big success by spreading the word and submitting your proposal! Follow us on Twitter ([@pulsarsummit](https://twitter.com/PulsarSummit)) to receive the latest updates of the conference!

Hope to see you at Pulsar Summit Asia 2020!

## About Apache Pulsar
Apache Pulsar is a cloud-native, distributed messaging and streaming platform that manages hundreds of billions of events per day. Pulsar was originally developed and deployed inside Yahoo as the consolidated messaging platform connecting critical Yahoo applications such as Yahoo Finance, Yahoo Mail, and Flickr, to data. Pulsar was contributed to open source by Yahoo in 2016 and became a top-level Apache Software Foundation project in 2018.

## About StreamNative
StreamNative is the organizer of Pulsar Summit Asia 2020. StreamNative is enabling organizations to build the next generation of messaging and event streaming applications. Leveraging Apache Pulsar and BookKeeper, we optimize for scalability and resiliency while reducing the overhead management and complexity required by incumbent technologies. We do this by offering Pulsar and StreamNative’s "products as a service". StreamNative is building a world-class team that is passionate about building amazing products and committed to customer success.

==> apache-pulsar-2.11.1-src.tar.gz: apache-pulsar-2.11.1-src/site2/website/blog/2020-09-01-pulsar-summit-asia-2020-cfp.md <==
---
author: Jennifer Huang  
authorURL: https://twitter.com/Jennife06125739  
title: "Pulsar Summit Asia 2020 CFP is now open"

---

The Pulsar Summit is an annual conference dedicated to the Apache Pulsar community. The summit brings together an international audience of CTOs/CIOs, developers, data architects, data scientists, Apache Pulsar committers/contributors, and the messaging and streaming community. Together, they share experiences, ideas, and insights on Pulsar and its growing community, and receive hands-on training sessions led by Pulsar experts.

<!--truncate-->

After a very successful Pulsar Summit Virtual Conference in June, we have decided to present our Pulsar Summit Asia 2020 in the same way on November 28-29, 2020. The two-day conference will be free to attend! Are you interested in presenting? Suggested topics include Pulsar use cases, operations, technology deep dive, and ecosystem. CFP and registration are now open!

![](/img/pulsar-summit-asia-2020.png)

## Speak at Pulsar Summit
The opportunity to speak at the second global Pulsar Summit is a great chance to participate in the rapidly growing Apache Pulsar community. Join us for the opportunity to be on stage with top Pulsar thought-leaders, including Apache Pulsar PMC members Sijie Guo and Jia Zhai from [StreamNative](https://streamnative.io/), Penghui Li from Zhaopin.com, Nozomi Kurihara from [Yahoo Japan Corporation](https://about.yahoo.co.jp/), and other community leaders such as Dezhi Liu from [Tencent](https://www.tencent.com/en-us), Vincent Xie from [Orange Finance](https://www.bestpay.com.cn/). Proposals for speaker presentations are currently being accepted. Suggested topics include Pulsar use cases, operations, technology deep dive, and ecosystem. Submissions are open until **October 14, 2020**.

If you have questions about submitting a proposal, or want some feedback or advice in general, please do not hesitate to reach out to [organizers@pulsar-summit.org](mailto:organizers@pulsar-summit.org). We are happy to help out! Details are available on the [CFP website](https://pulsar-summit.org/en/event/asia-2020/cfp).

## Dates to remember
- CFP opens: September 1, 2020
- CFP closes: October 21, 2020 - 23:59 (CST: China Standard Time/UTC+8 time zone)
- CFP notification: October 28, 2020
- Schedule announcement: November 4, 2020

## Speaker benefits
When your speaking proposal is approved, you will enjoy the following benefits:

- The opportunity to expand your network and raise your profile in the Apache Pulsar community.
- The chance to demonstrate your experience and deep knowledge in the rapidly growing event streaming space.
- Your name, title, company, and bio will be featured on the Pulsar Summit Asia 2020 website.
- Your session will be added to the Pulsar Summit YouTube Channel and promoted on Twitter and LinkedIn.
- A professionally produced video of your presentation.

## Speaker requirements
In addition to your talk, we ask that you actively participate in promoting the event via your personal and company channels. These include posting on your Twitter, LinkedIn, WeChat, Weibo, blog and other channels. We would also like to work directly with your marketing team on co-marketing opportunities. These include, but are not limited to, posting to your company’s Twitter, LinkedIn, WeChat and other developer communities and sending a dedicated Pulsar Summit email to your company’s email list. Contact us at [organizers@pulsar-summit.org](mailto:organizers@pulsar-summit.org) with any questions. 

## Registration
If you are interested in attending Pulsar Summit Asia 2020, please sign in Hopin and [checkout our event](https://hopin.to/events/pulsar-summit-asia-2020). Your ideas are very important to us, and we will prepare the content accordingly. 

After you checkout the event in Hopin, you will be notified with the event update at the first time when announcing.

## Sponsor Pulsar Summit
Pulsar Summit is a community run conference and your support is needed. Sponsoring this event will provide a great opportunity for your organization to further engage with the Apache Pulsar community. [Contact us](mailto:partners@pulsar-summit.org) to learn more.

Help us make #PulsarSummit 2020 a big success by spreading the word and submitting your proposal! Follow us on Twitter ([@pulsarsummit](https://twitter.com/PulsarSummit)) to receive the latest updates of the conference!

Hope to see you at Pulsar Summit Asia 2020!

## About Apache Pulsar
Apache Pulsar is a cloud-native, distributed messaging and streaming platform that manages hundreds of billions of events per day. Pulsar was originally developed and deployed inside Yahoo as the consolidated messaging platform connecting critical Yahoo applications such as Yahoo Finance, Yahoo Mail, and Flickr, to data. Pulsar was contributed to open source by Yahoo in 2016 and became a top-level Apache Software Foundation project in 2018.

## About StreamNative
StreamNative is the organizer of Pulsar Summit Asia 2020. StreamNative is enabling organizations to build the next generation of messaging and event streaming applications. Leveraging Apache Pulsar and BookKeeper, we optimize for scalability and resiliency while reducing the overhead management and complexity required by incumbent technologies. We do this by offering Pulsar and StreamNative’s "products as a service". StreamNative is building a world-class team that is passionate about building amazing products and committed to customer success.
